@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Type, Union, overload
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -83,7 +83,7 @@ __all__ = ("KMSClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -127,7 +127,7 @@ class Exceptions:
 
 class KMSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html)
     """
 
@@ -143,7 +143,7 @@ class KMSClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#can_paginate)
         """
 
@@ -151,7 +151,7 @@ class KMSClient(BaseClient):
         """
         Cancels the deletion of a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.cancel_key_deletion)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.cancel_key_deletion)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#cancel_key_deletion)
         """
 
@@ -161,7 +161,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__ to its associated CloudHSM cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.connect_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.connect_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#connect_custom_key_store)
         """
 
@@ -169,7 +169,7 @@ class KMSClient(BaseClient):
         """
         Creates a friendly name for a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.create_alias)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.create_alias)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_alias)
         """
 
@@ -188,7 +188,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/cloudhsm/latest/userguide/clusters.html>`__ that
         you own and manage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.create_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.create_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_custom_key_store)
         """
 
@@ -197,16 +197,16 @@ class KMSClient(BaseClient):
         *,
         KeyId: str,
         GranteePrincipal: str,
-        Operations: List[GrantOperationType],
+        Operations: Sequence[GrantOperationType],
         RetiringPrincipal: str = None,
         Constraints: "GrantConstraintsTypeDef" = None,
-        GrantTokens: List[str] = None,
+        GrantTokens: Sequence[str] = None,
         Name: str = None
     ) -> CreateGrantResponseTypeDef:
         """
         Adds a grant to a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.create_grant)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.create_grant)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_grant)
         """
 
@@ -221,7 +221,7 @@ class KMSClient(BaseClient):
         Origin: OriginTypeType = None,
         CustomKeyStoreId: str = None,
         BypassPolicyLockoutSafetyCheck: bool = None,
-        Tags: List["TagTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None,
         MultiRegion: bool = None
     ) -> CreateKeyResponseTypeDef:
         """
@@ -229,7 +229,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#kms-
         keys>`__ in your Amazon Web Services account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.create_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.create_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#create_key)
         """
 
@@ -237,8 +237,8 @@ class KMSClient(BaseClient):
         self,
         *,
         CiphertextBlob: Union[bytes, IO[bytes], StreamingBody],
-        EncryptionContext: Dict[str, str] = None,
-        GrantTokens: List[str] = None,
+        EncryptionContext: Mapping[str, str] = None,
+        GrantTokens: Sequence[str] = None,
         KeyId: str = None,
         EncryptionAlgorithm: EncryptionAlgorithmSpecType = None
     ) -> DecryptResponseTypeDef:
@@ -248,7 +248,7 @@ class KMSClient(BaseClient):
         GenerateDataKeyWithoutPlaintext *  GenerateDataKeyPairWithoutPlaintext You can
         use this operation to decrypt cipher...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.decrypt)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.decrypt)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#decrypt)
         """
 
@@ -256,7 +256,7 @@ class KMSClient(BaseClient):
         """
         Deletes the specified alias.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.delete_alias)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.delete_alias)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#delete_alias)
         """
 
@@ -266,7 +266,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.delete_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.delete_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#delete_custom_key_store)
         """
 
@@ -274,7 +274,7 @@ class KMSClient(BaseClient):
         """
         Deletes key material that you previously imported.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.delete_imported_key_material)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.delete_imported_key_material)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#delete_imported_key_material)
         """
 
@@ -291,17 +291,17 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__ in the account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.describe_custom_key_stores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.describe_custom_key_stores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#describe_custom_key_stores)
         """
 
     def describe_key(
-        self, *, KeyId: str, GrantTokens: List[str] = None
+        self, *, KeyId: str, GrantTokens: Sequence[str] = None
     ) -> DescribeKeyResponseTypeDef:
         """
         Provides detailed information about a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.describe_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.describe_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#describe_key)
         """
 
@@ -309,7 +309,7 @@ class KMSClient(BaseClient):
         """
         Sets the state of a KMS key to disabled.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.disable_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.disable_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#disable_key)
         """
 
@@ -319,7 +319,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html>`__ for
         the specified symmetric KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.disable_key_rotation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.disable_key_rotation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#disable_key_rotation)
         """
 
@@ -329,7 +329,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-
         overview.html>`__ from its associated CloudHSM cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.disconnect_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.disconnect_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#disconnect_custom_key_store)
         """
 
@@ -337,7 +337,7 @@ class KMSClient(BaseClient):
         """
         Sets the key state of a KMS key to enabled.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.enable_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.enable_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#enable_key)
         """
 
@@ -347,7 +347,7 @@ class KMSClient(BaseClient):
         <https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html>`__ for
         the specified symmetric KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.enable_key_rotation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.enable_key_rotation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#enable_key_rotation)
         """
 
@@ -356,14 +356,14 @@ class KMSClient(BaseClient):
         *,
         KeyId: str,
         Plaintext: Union[bytes, IO[bytes], StreamingBody],
-        EncryptionContext: Dict[str, str] = None,
-        GrantTokens: List[str] = None,
+        EncryptionContext: Mapping[str, str] = None,
+        GrantTokens: Sequence[str] = None,
         EncryptionAlgorithm: EncryptionAlgorithmSpecType = None
     ) -> EncryptResponseTypeDef:
         """
         Encrypts plaintext into ciphertext by using a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.encrypt)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.encrypt)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#encrypt)
         """
 
@@ -371,15 +371,15 @@ class KMSClient(BaseClient):
         self,
         *,
         KeyId: str,
-        EncryptionContext: Dict[str, str] = None,
+        EncryptionContext: Mapping[str, str] = None,
         NumberOfBytes: int = None,
         KeySpec: DataKeySpecType = None,
-        GrantTokens: List[str] = None
+        GrantTokens: Sequence[str] = None
     ) -> GenerateDataKeyResponseTypeDef:
         """
         Generates a unique symmetric data key for client-side encryption.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.generate_data_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.generate_data_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key)
         """
 
@@ -388,13 +388,13 @@ class KMSClient(BaseClient):
         *,
         KeyId: str,
         KeyPairSpec: DataKeyPairSpecType,
-        EncryptionContext: Dict[str, str] = None,
-        GrantTokens: List[str] = None
+        EncryptionContext: Mapping[str, str] = None,
+        GrantTokens: Sequence[str] = None
     ) -> GenerateDataKeyPairResponseTypeDef:
         """
         Generates a unique asymmetric data key pair.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.generate_data_key_pair)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.generate_data_key_pair)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key_pair)
         """
 
@@ -403,13 +403,13 @@ class KMSClient(BaseClient):
         *,
         KeyId: str,
         KeyPairSpec: DataKeyPairSpecType,
-        EncryptionContext: Dict[str, str] = None,
-        GrantTokens: List[str] = None
+        EncryptionContext: Mapping[str, str] = None,
+        GrantTokens: Sequence[str] = None
     ) -> GenerateDataKeyPairWithoutPlaintextResponseTypeDef:
         """
         Generates a unique asymmetric data key pair.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.generate_data_key_pair_without_plaintext)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.generate_data_key_pair_without_plaintext)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key_pair_without_plaintext)
         """
 
@@ -417,29 +417,29 @@ class KMSClient(BaseClient):
         self,
         *,
         KeyId: str,
-        EncryptionContext: Dict[str, str] = None,
+        EncryptionContext: Mapping[str, str] = None,
         KeySpec: DataKeySpecType = None,
         NumberOfBytes: int = None,
-        GrantTokens: List[str] = None
+        GrantTokens: Sequence[str] = None
     ) -> GenerateDataKeyWithoutPlaintextResponseTypeDef:
         """
         Generates a unique symmetric data key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.generate_data_key_without_plaintext)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.generate_data_key_without_plaintext)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_data_key_without_plaintext)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_presigned_url)
         """
 
@@ -449,7 +449,7 @@ class KMSClient(BaseClient):
         """
         Returns a random byte string that is cryptographically secure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.generate_random)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.generate_random)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#generate_random)
         """
 
@@ -457,7 +457,7 @@ class KMSClient(BaseClient):
         """
         Gets a key policy attached to the specified KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.get_key_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.get_key_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_key_policy)
         """
 
@@ -467,7 +467,7 @@ class KMSClient(BaseClient):
         material <https://docs.aws.amazon.com/kms/latest/developerguide/rotate-
         keys.html>`__ is enabled for the specified KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.get_key_rotation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.get_key_rotation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_key_rotation_status)
         """
 
@@ -482,17 +482,17 @@ class KMSClient(BaseClient):
         Returns the items you need to import key material into a symmetric, customer
         managed KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.get_parameters_for_import)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.get_parameters_for_import)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_parameters_for_import)
         """
 
     def get_public_key(
-        self, *, KeyId: str, GrantTokens: List[str] = None
+        self, *, KeyId: str, GrantTokens: Sequence[str] = None
     ) -> GetPublicKeyResponseTypeDef:
         """
         Returns the public key of an asymmetric KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.get_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.get_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#get_public_key)
         """
 
@@ -509,7 +509,7 @@ class KMSClient(BaseClient):
         Imports key material into an existing symmetric KMS KMS key that was created
         without key material.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.import_key_material)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.import_key_material)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#import_key_material)
         """
 
@@ -519,7 +519,7 @@ class KMSClient(BaseClient):
         """
         Gets a list of aliases in the caller's Amazon Web Services account and region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.list_aliases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.list_aliases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_aliases)
         """
 
@@ -535,7 +535,7 @@ class KMSClient(BaseClient):
         """
         Gets a list of all grants for the specified KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.list_grants)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.list_grants)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_grants)
         """
 
@@ -545,7 +545,7 @@ class KMSClient(BaseClient):
         """
         Gets the names of the key policies that are attached to a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.list_key_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.list_key_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_key_policies)
         """
 
@@ -554,7 +554,7 @@ class KMSClient(BaseClient):
         Gets a list of all KMS keys in the caller's Amazon Web Services account and
         Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.list_keys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.list_keys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_keys)
         """
 
@@ -564,7 +564,7 @@ class KMSClient(BaseClient):
         """
         Returns all tags on the specified KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.list_resource_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.list_resource_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_resource_tags)
         """
 
@@ -575,7 +575,7 @@ class KMSClient(BaseClient):
         Returns information about all grants in the Amazon Web Services account and
         Region that have the specified retiring principal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.list_retirable_grants)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.list_retirable_grants)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#list_retirable_grants)
         """
 
@@ -590,7 +590,7 @@ class KMSClient(BaseClient):
         """
         Attaches a key policy to the specified KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.put_key_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.put_key_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#put_key_policy)
         """
 
@@ -599,17 +599,17 @@ class KMSClient(BaseClient):
         *,
         CiphertextBlob: Union[bytes, IO[bytes], StreamingBody],
         DestinationKeyId: str,
-        SourceEncryptionContext: Dict[str, str] = None,
+        SourceEncryptionContext: Mapping[str, str] = None,
         SourceKeyId: str = None,
-        DestinationEncryptionContext: Dict[str, str] = None,
+        DestinationEncryptionContext: Mapping[str, str] = None,
         SourceEncryptionAlgorithm: EncryptionAlgorithmSpecType = None,
         DestinationEncryptionAlgorithm: EncryptionAlgorithmSpecType = None,
-        GrantTokens: List[str] = None
+        GrantTokens: Sequence[str] = None
     ) -> ReEncryptResponseTypeDef:
         """
         Decrypts ciphertext and then reencrypts it entirely within KMS.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.re_encrypt)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.re_encrypt)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#re_encrypt)
         """
 
@@ -621,12 +621,12 @@ class KMSClient(BaseClient):
         Policy: str = None,
         BypassPolicyLockoutSafetyCheck: bool = None,
         Description: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> ReplicateKeyResponseTypeDef:
         """
         Replicates a multi-Region key into the specified Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.replicate_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.replicate_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#replicate_key)
         """
 
@@ -636,7 +636,7 @@ class KMSClient(BaseClient):
         """
         Deletes a grant.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.retire_grant)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.retire_grant)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#retire_grant)
         """
 
@@ -644,7 +644,7 @@ class KMSClient(BaseClient):
         """
         Deletes the specified grant.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.revoke_grant)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.revoke_grant)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#revoke_grant)
         """
 
@@ -654,7 +654,7 @@ class KMSClient(BaseClient):
         """
         Schedules the deletion of a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.schedule_key_deletion)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.schedule_key_deletion)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#schedule_key_deletion)
         """
 
@@ -665,34 +665,34 @@ class KMSClient(BaseClient):
         Message: Union[bytes, IO[bytes], StreamingBody],
         SigningAlgorithm: SigningAlgorithmSpecType,
         MessageType: MessageTypeType = None,
-        GrantTokens: List[str] = None
+        GrantTokens: Sequence[str] = None
     ) -> SignResponseTypeDef:
         """
         Creates a `digital signature
         <https://en.wikipedia.org/wiki/Digital_signature>`__ for a message or message
         digest by using the private key in an asymmetric KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.sign)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.sign)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#sign)
         """
 
-    def tag_resource(self, *, KeyId: str, Tags: List["TagTypeDef"]) -> None:
+    def tag_resource(self, *, KeyId: str, Tags: Sequence["TagTypeDef"]) -> None:
         """
         Adds or edits tags on a `customer managed key
         <https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-
         cmk>`__ .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, KeyId: str, TagKeys: List[str]) -> None:
+    def untag_resource(self, *, KeyId: str, TagKeys: Sequence[str]) -> None:
         """
         Deletes tags from a `customer managed key
         <https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-
         cmk>`__.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#untag_resource)
         """
 
@@ -700,7 +700,7 @@ class KMSClient(BaseClient):
         """
         Associates an existing KMS alias with a different KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.update_alias)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.update_alias)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_alias)
         """
 
@@ -715,7 +715,7 @@ class KMSClient(BaseClient):
         """
         Changes the properties of a custom key store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.update_custom_key_store)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.update_custom_key_store)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_custom_key_store)
         """
 
@@ -723,7 +723,7 @@ class KMSClient(BaseClient):
         """
         Updates the description of a KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.update_key_description)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.update_key_description)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_key_description)
         """
 
@@ -731,7 +731,7 @@ class KMSClient(BaseClient):
         """
         Changes the primary key of a multi-Region key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.update_primary_region)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.update_primary_region)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#update_primary_region)
         """
 
@@ -743,26 +743,26 @@ class KMSClient(BaseClient):
         Signature: Union[bytes, IO[bytes], StreamingBody],
         SigningAlgorithm: SigningAlgorithmSpecType,
         MessageType: MessageTypeType = None,
-        GrantTokens: List[str] = None
+        GrantTokens: Sequence[str] = None
     ) -> VerifyResponseTypeDef:
         """
         Verifies a digital signature that was generated by the  Sign operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Client.verify)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Client.verify)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/client.html#verify)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_aliases"]) -> ListAliasesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Paginator.ListAliases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Paginator.ListAliases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listaliasespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_grants"]) -> ListGrantsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Paginator.ListGrants)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Paginator.ListGrants)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listgrantspaginator)
         """
 
@@ -771,13 +771,13 @@ class KMSClient(BaseClient):
         self, operation_name: Literal["list_key_policies"]
     ) -> ListKeyPoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listkeypoliciespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_keys"]) -> ListKeysPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/kms.html#KMS.Paginator.ListKeys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/kms.html#KMS.Paginator.ListKeys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/paginators.html#listkeyspaginator)
         """
